searchData={"items":[{"type":"module","title":"Nik","doc":"Functions for working with NIK (Nomor Induk Kependudukan)\n\nNIK consists of 16 digits that divided into 7 parts:\n- `2` digits for Province Code (`11-92`)\n- `2` digits for City Code (`01-99`)\n- `2` digits for Subdistrict Code (`01-99`)\n- `2` digits for Birth Day (`01-31`), if the person is female, the date will be added by `40`\n- `2` digits for Birth Month (`01-12`)\n- `2` digits for Birth Year (`YY`)\n- `4` digits for serial number (`0001-9999`) that is determined by system","ref":"Nik.html"},{"type":"function","title":"Nik.parse/1","doc":"Parse NIK into a struct.\n\nReturns `{:ok, %Nik{}}` if the NIK is valid, otherwise `{:error, reason}`.","ref":"Nik.html#parse/1"},{"type":"function","title":"Examples - Nik.parse/1","doc":"iex> Nik.parse(\"7210142507971234\")\n    {:ok,\n     %Nik{\n       id: \"7210142507971234\",\n       area: %{\n         city: %{\"code\" => \"10\", \"name\" => \"Sigi\", \"type\" => \"Kabupaten\"},\n         district: %{\"code\" => \"14\", \"name\" => \"Marawola\", \"type\" => \"Kecamatan\"},\n         province: %{\"code\" => \"72\", \"name\" => \"Sulawesi Tengah\"}\n       },\n       birth_date: ~D[1997-07-25],\n       sex: \"M\",\n       serial_number: \"1234\"\n    }}","ref":"Nik.html#parse/1-examples"},{"type":"type","title":"Nik.result/0","doc":"","ref":"Nik.html#t:result/0"},{"type":"type","title":"Nik.t/0","doc":"","ref":"Nik.html#t:t/0"},{"type":"module","title":"Nip.Pns","doc":"Functions for working with NIP PNS (Nomor Induk Pegawai Negeri Sipil)\n\nNIP PNS consists of 18 digits divided into 4 parts:\n- `8` digits for birth date (`YYYYMMDD`)\n- `6` digits for TMT (Tanggal Mulai Tugas) (`YYYYMM`)\n- `1` digit for sex code (`1` for male and `2` for female)\n- `3` digits for serial number (`001-999`)","ref":"Nip.Pns.html"},{"type":"type","title":"Nip.Pns.nip_result/0","doc":"","ref":"Nip.Pns.html#t:nip_result/0"},{"type":"function","title":"Nip.Pns.parse/1","doc":"Parse NIP PNS into a struct.\n\nReturns `{:ok, %Nip.Pns{}}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pns.html#parse/1"},{"type":"function","title":"Examples - Nip.Pns.parse/1","doc":"iex> Nip.Pns.parse(\"200012312024121001\")\n    {:ok,\n    %Nip.Pns{\n      nip: \"200012312024121001\",\n      birth_date: ~D[2000-12-31],\n      tmt_date: ~D[2024-12-01],\n      sex: \"M\",\n      serial_number: \"001\"\n    }}","ref":"Nip.Pns.html#parse/1-examples"},{"type":"type","title":"Nip.Pns.t/0","doc":"","ref":"Nip.Pns.html#t:t/0"},{"type":"function","title":"Nip.Pns.validate_format/1","doc":"Validate NIP format.\n\nReturns `{:ok, nip}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pns.html#validate_format/1"},{"type":"function","title":"Examples - Nip.Pns.validate_format/1","doc":"iex> Nip.Pns.validate_format(\"200012312024121001\")\n    {:ok, \"200012312024121001\"}","ref":"Nip.Pns.html#validate_format/1-examples"},{"type":"type","title":"Nip.Pns.validated_nip_result/0","doc":"","ref":"Nip.Pns.html#t:validated_nip_result/0"},{"type":"module","title":"Nip.Pppk","doc":"Functions for working with NIP PPPK (Pegawai Pemerintah dengan Perjanjian Kerja)\n\nNIP PPPK consists of 18 digits divided into 6 parts:\n- `8` digits for birth date (`YYYYMMDD`)\n- `4` digits for TMT (Tanggal Mulai Tugas) (`YYYY`)\n- `1` digit that indicates the code for PPPK (`2`)\n- `1` digit for frequency (`1-9`)\n- `1` digit for sex code (`1` for male and `2` for female)\n- `3` digits for serial number (`001-999`)","ref":"Nip.Pppk.html"},{"type":"type","title":"Nip.Pppk.nip_result/0","doc":"","ref":"Nip.Pppk.html#t:nip_result/0"},{"type":"function","title":"Nip.Pppk.parse/1","doc":"Parse NIP PPPK into a struct.\n\nThis function returns `{:ok, %Nip.Pppk{}}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pppk.html#parse/1"},{"type":"function","title":"Examples - Nip.Pppk.parse/1","doc":"iex> Nip.Pppk.parse(\"200012312024211001\")\n    {:ok,\n    %Nip.Pppk{\n      nip: \"200012312024211001\",\n      birth_date: ~D[2000-12-31],\n      tmt_date: ~D[2024-01-01],\n      frequency: 1,\n      sex: \"M\",\n      serial_number: \"001\"\n    }}","ref":"Nip.Pppk.html#parse/1-examples"},{"type":"type","title":"Nip.Pppk.t/0","doc":"","ref":"Nip.Pppk.html#t:t/0"},{"type":"function","title":"Nip.Pppk.validate_format/1","doc":"Validate NIP format.\n\nThis function returns `{:ok, nip}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pppk.html#validate_format/1"},{"type":"function","title":"Examples - Nip.Pppk.validate_format/1","doc":"iex> Nip.Pppk.validate_format(\"200012312024211001\")\n    {:ok, \"200012312024211001\"}","ref":"Nip.Pppk.html#validate_format/1-examples"},{"type":"type","title":"Nip.Pppk.validated_nip_result/0","doc":"","ref":"Nip.Pppk.html#t:validated_nip_result/0"},{"type":"module","title":"Regional","doc":"Functions for looking up regional codes based on Permendagri No. 72/2019.","ref":"Regional.html"},{"type":"function","title":"Regional.find_city/1","doc":"Find city by province and city codes.\n\nReturns `{:ok, %{city_data}}` if the city is found, otherwise `{:error, \"City data not found\"}`.","ref":"Regional.html#find_city/1"},{"type":"function","title":"Examples - Regional.find_city/1","doc":"iex> Regional.find_city(%{province_code: \"72\", city_code: \"10\"})\n    {:ok, %{\"code\" => \"10\", \"type\" => \"Kabupaten\", \"name\" => \"Sigi\"}}","ref":"Regional.html#find_city/1-examples"},{"type":"function","title":"Regional.find_district/1","doc":"Find district by province, city, and district codes.\n\nReturns `{:ok, %{district_data}}` if the district is found, otherwise\n`{:error, \"District data not found\"}`.","ref":"Regional.html#find_district/1"},{"type":"function","title":"Examples - Regional.find_district/1","doc":"iex> Regional.find_district(%{province_code: \"72\", city_code: \"10\", district_code: \"14\"})\n    {:ok, %{\"code\" => \"14\", \"type\" => \"Kecamatan\", \"name\" => \"Marawola\"}}","ref":"Regional.html#find_district/1-examples"},{"type":"function","title":"Regional.find_province/1","doc":"Find province by code.\n\nReturns `{:ok, %{province_data}}` if the province is found, otherwise\n`{:error, \"Province data not found\"}`.","ref":"Regional.html#find_province/1"},{"type":"function","title":"Examples - Regional.find_province/1","doc":"iex> Regional.find_province(%{province_code: \"72\"})\n    {:ok, %{\"code\" => \"72\", \"name\" => \"Sulawesi Tengah\"}}","ref":"Regional.html#find_province/1-examples"},{"type":"function","title":"Regional.find_subdistrict/1","doc":"Find subdistrict by province, city, district, and subdistrict codes.\n\nReturns `{:ok, %{subdistrict_data}}` if the subdistrict is found, otherwise\n`{:error, \"Subdistrict data not found\"}`.","ref":"Regional.html#find_subdistrict/1"},{"type":"function","title":"Examples - Regional.find_subdistrict/1","doc":"iex> Regional.find_subdistrict(%{province_code: \"72\", city_code: \"10\", district_code: \"14\", subdistrict_code: \"2007\"})\n    {:ok, %{\"code\" => \"2007\", \"type\" => \"Desa\", \"name\" => \"Tinggede\"}}","ref":"Regional.html#find_subdistrict/1-examples"},{"type":"type","title":"Regional.regional_data/0","doc":"","ref":"Regional.html#t:regional_data/0"},{"type":"extras","title":"indonesian_id","doc":"# indonesian_id\n\n![Hex.pm Version](https://img.shields.io/hexpm/v/indonesian_id) ![Hex.pm Downloads](https://img.shields.io/hexpm/dt/indonesian_id) [![Elixir CI](https://github.com/muzhawir/indonesian_id/actions/workflows/elixir.yml/badge.svg?branch=main)](https://github.com/muzhawir/indonesian_id/actions/workflows/elixir.yml)\n\nPackage for parsing and looking-up various Indonesian ID numbers or codes.","ref":"readme.html"},{"type":"extras","title":"Installation - indonesian_id","doc":"Add `indonesian_id` to your list of dependencies in `mix.exs` to install it from [Hex](https://hex.pm/packages/indonesian_id):\n\n```elixir\ndef deps do\n  [\n    {:indonesian_id, \"~> 1.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}